﻿using System.Configuration;
using System.Globalization;
using Microsoft.Practices.Unity;
using Microsoft.Practices.Unity.Configuration;
using Microsoft.Practices.Unity.InterceptionExtension;
using System.Web;

namespace WcfServer.Common
{
    public static class ServiceLocator
    {
        // private static readonly InterfaceInterceptor  injector = new InterfaceInterceptor ();

        private static readonly TransparentProxyInterceptor injector = new TransparentProxyInterceptor();

        public static IUnityContainer Container
        {
            get;
            private set;
        }
        static ServiceLocator()
        {

            Container = new UnityContainer();
            UnityConfigurationSection unitySection = ConfigurationManager.GetSection("unity") as UnityConfigurationSection;
            if (unitySection == null)
            {
                throw new ConfigurationErrorsException(string.Format(CultureInfo.CurrentCulture, "missing unity configuration section"));
            }
            Container.AddNewExtension<Interception>();

            unitySection.Configure(Container, "DSNUnityContainer");

        }
        /// <summary>
        /// 没有为映射指定别名
        /// name属性没有赋值
        /// </summary>
        /// <typeparam name="T"></typeparam>
        /// <returns></returns>
        public static T LoadService<T>()
        {
            Container.Configure<Interception>().SetDefaultInterceptorFor<T>(injector);
            return Container.Resolve<T>();
        }
        /// <summary>
        /// 为映射指定别名
        /// name属性赋值
        /// </summary>
        /// <typeparam name="T"></typeparam>
        /// <param name="serviceName"></param>
        /// <returns></returns>
        public static T LoadService<T>(string serviceName)
        {
            Container.Configure<Interception>().SetDefaultInterceptorFor<T>(injector);
            return Container.Resolve<T>(serviceName);
        }
    }
}